# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_get200_response_audit_logs_inner_event import ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent

class ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner(BaseModel):
    """
    ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner
    """
    id: StrictStr = Field(...)
    ip_address: Optional[StrictStr] = Field(default=None, alias="ipAddress")
    user_agent: Optional[StrictStr] = Field(default=None, alias="userAgent")
    user_agent_type: Optional[StrictStr] = Field(default=None, alias="userAgentType")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    org_id: Optional[StrictStr] = Field(default=None, alias="orgId")
    project_id: Optional[StrictStr] = Field(default=None, alias="projectId")
    event: ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent = Field(...)
    actor: ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent = Field(...)
    __properties = ["id", "ipAddress", "userAgent", "userAgentType", "expiresAt", "createdAt", "updatedAt", "orgId", "projectId", "event", "actor"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of event
        if self.event:
            _dict['event'] = self.event.to_dict()
        # override the default output from pydantic by calling `to_dict()` of actor
        if self.actor:
            _dict['actor'] = self.actor.to_dict()
        # set to None if ip_address (nullable) is None
        # and __fields_set__ contains the field
        if self.ip_address is None and "ip_address" in self.__fields_set__:
            _dict['ipAddress'] = None

        # set to None if user_agent (nullable) is None
        # and __fields_set__ contains the field
        if self.user_agent is None and "user_agent" in self.__fields_set__:
            _dict['userAgent'] = None

        # set to None if user_agent_type (nullable) is None
        # and __fields_set__ contains the field
        if self.user_agent_type is None and "user_agent_type" in self.__fields_set__:
            _dict['userAgentType'] = None

        # set to None if expires_at (nullable) is None
        # and __fields_set__ contains the field
        if self.expires_at is None and "expires_at" in self.__fields_set__:
            _dict['expiresAt'] = None

        # set to None if org_id (nullable) is None
        # and __fields_set__ contains the field
        if self.org_id is None and "org_id" in self.__fields_set__:
            _dict['orgId'] = None

        # set to None if project_id (nullable) is None
        # and __fields_set__ contains the field
        if self.project_id is None and "project_id" in self.__fields_set__:
            _dict['projectId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner.parse_obj(obj)

        _obj = ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner.parse_obj({
            "id": obj.get("id"),
            "ip_address": obj.get("ipAddress"),
            "user_agent": obj.get("userAgent"),
            "user_agent_type": obj.get("userAgentType"),
            "expires_at": obj.get("expiresAt"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "org_id": obj.get("orgId"),
            "project_id": obj.get("projectId"),
            "event": ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent.from_dict(obj.get("event")) if obj.get("event") is not None else None,
            "actor": ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent.from_dict(obj.get("actor")) if obj.get("actor") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_commits_inner_secret import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecret
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_commits_inner_secret_version import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecretVersion
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner_tags_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInnerTagsInner

class ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner(BaseModel):
    """
    ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner
    """
    id: StrictStr = Field(...)
    secret_key: StrictStr = Field(default=..., alias="secretKey")
    secret_value: StrictStr = Field(default=..., alias="secretValue")
    secret_comment: StrictStr = Field(default=..., alias="secretComment")
    secret_reminder_note: Optional[StrictStr] = Field(default=None, alias="secretReminderNote")
    secret_reminder_repeat_days: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="secretReminderRepeatDays")
    skip_multiline_encoding: Optional[StrictBool] = Field(default=False, alias="skipMultilineEncoding")
    metadata: Optional[Any] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    op: StrictStr = Field(...)
    tags: Optional[conlist(ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInnerTagsInner)] = None
    secret: Optional[ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecret] = None
    secret_version: Optional[ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecretVersion] = Field(default=None, alias="secretVersion")
    __properties = ["id", "secretKey", "secretValue", "secretComment", "secretReminderNote", "secretReminderRepeatDays", "skipMultilineEncoding", "metadata", "createdAt", "updatedAt", "op", "tags", "secret", "secretVersion"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item in self.tags:
                if _item:
                    _items.append(_item.to_dict())
            _dict['tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of secret
        if self.secret:
            _dict['secret'] = self.secret.to_dict()
        # override the default output from pydantic by calling `to_dict()` of secret_version
        if self.secret_version:
            _dict['secretVersion'] = self.secret_version.to_dict()
        # set to None if secret_reminder_note (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_note is None and "secret_reminder_note" in self.__fields_set__:
            _dict['secretReminderNote'] = None

        # set to None if secret_reminder_repeat_days (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_repeat_days is None and "secret_reminder_repeat_days" in self.__fields_set__:
            _dict['secretReminderRepeatDays'] = None

        # set to None if skip_multiline_encoding (nullable) is None
        # and __fields_set__ contains the field
        if self.skip_multiline_encoding is None and "skip_multiline_encoding" in self.__fields_set__:
            _dict['skipMultilineEncoding'] = None

        # set to None if metadata (nullable) is None
        # and __fields_set__ contains the field
        if self.metadata is None and "metadata" in self.__fields_set__:
            _dict['metadata'] = None

        # set to None if secret (nullable) is None
        # and __fields_set__ contains the field
        if self.secret is None and "secret" in self.__fields_set__:
            _dict['secret'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner.parse_obj({
            "id": obj.get("id"),
            "secret_key": obj.get("secretKey"),
            "secret_value": obj.get("secretValue"),
            "secret_comment": obj.get("secretComment"),
            "secret_reminder_note": obj.get("secretReminderNote"),
            "secret_reminder_repeat_days": obj.get("secretReminderRepeatDays"),
            "skip_multiline_encoding": obj.get("skipMultilineEncoding") if obj.get("skipMultilineEncoding") is not None else False,
            "metadata": obj.get("metadata"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "op": obj.get("op"),
            "tags": [ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInnerTagsInner.from_dict(_item) for _item in obj.get("tags")] if obj.get("tags") is not None else None,
            "secret": ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecret.from_dict(obj.get("secret")) if obj.get("secret") is not None else None,
            "secret_version": ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecretVersion.from_dict(obj.get("secretVersion")) if obj.get("secretVersion") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_integration_post200_response import ApiV1IntegrationPost200Response  # noqa: E501

class TestApiV1IntegrationPost200Response(unittest.TestCase):
    """ApiV1IntegrationPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1IntegrationPost200Response:
        """Test ApiV1IntegrationPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1IntegrationPost200Response`
        """
        model = ApiV1IntegrationPost200Response()  # noqa: E501
        if include_optional:
            return ApiV1IntegrationPost200Response(
                integration = infisicalapi_client.models._api_v1_integration_post_200_response_integration._api_v1_integration_post_200_response_integration(
                    id = '', 
                    is_active = True, 
                    url = '', 
                    app = '', 
                    app_id = '', 
                    target_environment = '', 
                    target_environment_id = '', 
                    target_service = '', 
                    target_service_id = '', 
                    owner = '', 
                    path = '', 
                    region = '', 
                    scope = '', 
                    integration = '', 
                    metadata = null, 
                    integration_auth_id = '', 
                    env_id = '', 
                    secret_path = '/', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_synced = True, 
                    sync_message = '', 
                    last_sync_job_id = '', )
            )
        else:
            return ApiV1IntegrationPost200Response(
                integration = infisicalapi_client.models._api_v1_integration_post_200_response_integration._api_v1_integration_post_200_response_integration(
                    id = '', 
                    is_active = True, 
                    url = '', 
                    app = '', 
                    app_id = '', 
                    target_environment = '', 
                    target_environment_id = '', 
                    target_service = '', 
                    target_service_id = '', 
                    owner = '', 
                    path = '', 
                    region = '', 
                    scope = '', 
                    integration = '', 
                    metadata = null, 
                    integration_auth_id = '', 
                    env_id = '', 
                    secret_path = '/', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_synced = True, 
                    sync_message = '', 
                    last_sync_job_id = '', ),
        )
        """

    def testApiV1IntegrationPost200Response(self):
        """Test ApiV1IntegrationPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1DynamicSecretsNamePatchRequestData(BaseModel):
    """
    ApiV1DynamicSecretsNamePatchRequestData
    """
    inputs: Optional[Any] = Field(default=None, description="The new partial values for the configurated provider of the dynamic secret")
    default_ttl: Optional[StrictStr] = Field(default=None, alias="defaultTTL", description="The default TTL that will be applied for all the leases.")
    max_ttl: Optional[StrictStr] = Field(default=None, alias="maxTTL", description="The maximum limit a TTL can be leases or renewed.")
    new_name: Optional[StrictStr] = Field(default=None, alias="newName", description="The new name for the dynamic secret.")
    __properties = ["inputs", "defaultTTL", "maxTTL", "newName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsNamePatchRequestData:
        """Create an instance of ApiV1DynamicSecretsNamePatchRequestData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if inputs (nullable) is None
        # and __fields_set__ contains the field
        if self.inputs is None and "inputs" in self.__fields_set__:
            _dict['inputs'] = None

        # set to None if max_ttl (nullable) is None
        # and __fields_set__ contains the field
        if self.max_ttl is None and "max_ttl" in self.__fields_set__:
            _dict['maxTTL'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsNamePatchRequestData:
        """Create an instance of ApiV1DynamicSecretsNamePatchRequestData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsNamePatchRequestData.parse_obj(obj)

        _obj = ApiV1DynamicSecretsNamePatchRequestData.parse_obj({
            "inputs": obj.get("inputs"),
            "default_ttl": obj.get("defaultTTL"),
            "max_ttl": obj.get("maxTTL"),
            "new_name": obj.get("newName")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, validator
from infisicalapi_client.models.api_v1_audit_log_streams_id_get200_response_audit_log_stream_headers_inner import ApiV1AuditLogStreamsIdGet200ResponseAuditLogStreamHeadersInner
from infisicalapi_client.models.api_v1_integration_post_request_metadata_secret_gcp_label import ApiV1IntegrationPostRequestMetadataSecretGCPLabel

class ApiV1IntegrationIntegrationIdPatchRequestMetadata(BaseModel):
    """
    ApiV1IntegrationIntegrationIdPatchRequestMetadata
    """
    secret_prefix: Optional[StrictStr] = Field(default=None, alias="secretPrefix", description="The prefix for the saved secret. Used by GCP.")
    secret_suffix: Optional[StrictStr] = Field(default=None, alias="secretSuffix", description="The suffix for the saved secret. Used by GCP.")
    initial_sync_behavior: Optional[StrictStr] = Field(default=None, alias="initialSyncBehavior", description="Type of syncing behavoir with the integration.")
    mapping_behavior: Optional[StrictStr] = Field(default=None, alias="mappingBehavior", description="The mapping behavior of the integration.")
    should_auto_redeploy: Optional[StrictBool] = Field(default=None, alias="shouldAutoRedeploy", description="Used by Render to trigger auto deploy.")
    secret_gcp_label: Optional[ApiV1IntegrationPostRequestMetadataSecretGCPLabel] = Field(default=None, alias="secretGCPLabel")
    secret_aws_tag: Optional[conlist(ApiV1AuditLogStreamsIdGet200ResponseAuditLogStreamHeadersInner)] = Field(default=None, alias="secretAWSTag", description="The tags for AWS secrets.")
    kms_key_id: Optional[StrictStr] = Field(default=None, alias="kmsKeyId", description="The ID of the encryption key from AWS KMS.")
    should_disable_delete: Optional[StrictBool] = Field(default=None, alias="shouldDisableDelete", description="The flag to disable deletion of secrets in AWS Parameter Store.")
    should_enable_delete: Optional[StrictBool] = Field(default=None, alias="shouldEnableDelete", description="The flag to enable deletion of secrets")
    should_mask_secrets: Optional[StrictBool] = Field(default=None, alias="shouldMaskSecrets", description="Specifies if the secrets synced from Infisical to Gitlab should be marked as 'Masked'.")
    should_protect_secrets: Optional[StrictBool] = Field(default=None, alias="shouldProtectSecrets", description="Specifies if the secrets synced from Infisical to Gitlab should be marked as 'Protected'.")
    __properties = ["secretPrefix", "secretSuffix", "initialSyncBehavior", "mappingBehavior", "shouldAutoRedeploy", "secretGCPLabel", "secretAWSTag", "kmsKeyId", "shouldDisableDelete", "shouldEnableDelete", "shouldMaskSecrets", "shouldProtectSecrets"]

    @validator('mapping_behavior')
    def mapping_behavior_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('one-to-one', 'many-to-one'):
            raise ValueError("must be one of enum values ('one-to-one', 'many-to-one')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1IntegrationIntegrationIdPatchRequestMetadata:
        """Create an instance of ApiV1IntegrationIntegrationIdPatchRequestMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of secret_gcp_label
        if self.secret_gcp_label:
            _dict['secretGCPLabel'] = self.secret_gcp_label.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in secret_aws_tag (list)
        _items = []
        if self.secret_aws_tag:
            for _item in self.secret_aws_tag:
                if _item:
                    _items.append(_item.to_dict())
            _dict['secretAWSTag'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1IntegrationIntegrationIdPatchRequestMetadata:
        """Create an instance of ApiV1IntegrationIntegrationIdPatchRequestMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1IntegrationIntegrationIdPatchRequestMetadata.parse_obj(obj)

        _obj = ApiV1IntegrationIntegrationIdPatchRequestMetadata.parse_obj({
            "secret_prefix": obj.get("secretPrefix"),
            "secret_suffix": obj.get("secretSuffix"),
            "initial_sync_behavior": obj.get("initialSyncBehavior"),
            "mapping_behavior": obj.get("mappingBehavior"),
            "should_auto_redeploy": obj.get("shouldAutoRedeploy"),
            "secret_gcp_label": ApiV1IntegrationPostRequestMetadataSecretGCPLabel.from_dict(obj.get("secretGCPLabel")) if obj.get("secretGCPLabel") is not None else None,
            "secret_aws_tag": [ApiV1AuditLogStreamsIdGet200ResponseAuditLogStreamHeadersInner.from_dict(_item) for _item in obj.get("secretAWSTag")] if obj.get("secretAWSTag") is not None else None,
            "kms_key_id": obj.get("kmsKeyId"),
            "should_disable_delete": obj.get("shouldDisableDelete"),
            "should_enable_delete": obj.get("shouldEnableDelete"),
            "should_mask_secrets": obj.get("shouldMaskSecrets"),
            "should_protect_secrets": obj.get("shouldProtectSecrets")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_environment import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotEnvironment
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_folder_version_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotFolderVersionInner
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner

class ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot(BaseModel):
    """
    ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot
    """
    id: StrictStr = Field(...)
    project_id: StrictStr = Field(default=..., alias="projectId")
    environment: ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotEnvironment = Field(...)
    secret_versions: conlist(ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner) = Field(default=..., alias="secretVersions")
    folder_version: conlist(ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotFolderVersionInner) = Field(default=..., alias="folderVersion")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    __properties = ["id", "projectId", "environment", "secretVersions", "folderVersion", "createdAt", "updatedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot:
        """Create an instance of ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in secret_versions (list)
        _items = []
        if self.secret_versions:
            for _item in self.secret_versions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['secretVersions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in folder_version (list)
        _items = []
        if self.folder_version:
            for _item in self.folder_version:
                if _item:
                    _items.append(_item.to_dict())
            _dict['folderVersion'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot:
        """Create an instance of ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot.parse_obj(obj)

        _obj = ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot.parse_obj({
            "id": obj.get("id"),
            "project_id": obj.get("projectId"),
            "environment": ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotEnvironment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None,
            "secret_versions": [ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner.from_dict(_item) for _item in obj.get("secretVersions")] if obj.get("secretVersions") is not None else None,
            "folder_version": [ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotFolderVersionInner.from_dict(_item) for _item in obj.get("folderVersion")] if obj.get("folderVersion") is not None else None,
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_policy import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPolicy
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_privilege import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPrivilege
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_reviewers_inner import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerReviewersInner

class ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner(BaseModel):
    """
    ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner
    """
    id: StrictStr = Field(...)
    policy_id: StrictStr = Field(default=..., alias="policyId")
    privilege_id: Optional[StrictStr] = Field(default=None, alias="privilegeId")
    requested_by: StrictStr = Field(default=..., alias="requestedBy")
    is_temporary: StrictBool = Field(default=..., alias="isTemporary")
    temporary_range: Optional[StrictStr] = Field(default=None, alias="temporaryRange")
    permissions: Optional[Any] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    environment_name: StrictStr = Field(default=..., alias="environmentName")
    is_approved: StrictBool = Field(default=..., alias="isApproved")
    privilege: Optional[ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPrivilege] = Field(...)
    policy: ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPolicy = Field(...)
    reviewers: conlist(ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerReviewersInner) = Field(...)
    __properties = ["id", "policyId", "privilegeId", "requestedBy", "isTemporary", "temporaryRange", "permissions", "createdAt", "updatedAt", "environmentName", "isApproved", "privilege", "policy", "reviewers"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner:
        """Create an instance of ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of privilege
        if self.privilege:
            _dict['privilege'] = self.privilege.to_dict()
        # override the default output from pydantic by calling `to_dict()` of policy
        if self.policy:
            _dict['policy'] = self.policy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in reviewers (list)
        _items = []
        if self.reviewers:
            for _item in self.reviewers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['reviewers'] = _items
        # set to None if privilege_id (nullable) is None
        # and __fields_set__ contains the field
        if self.privilege_id is None and "privilege_id" in self.__fields_set__:
            _dict['privilegeId'] = None

        # set to None if temporary_range (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_range is None and "temporary_range" in self.__fields_set__:
            _dict['temporaryRange'] = None

        # set to None if permissions (nullable) is None
        # and __fields_set__ contains the field
        if self.permissions is None and "permissions" in self.__fields_set__:
            _dict['permissions'] = None

        # set to None if privilege (nullable) is None
        # and __fields_set__ contains the field
        if self.privilege is None and "privilege" in self.__fields_set__:
            _dict['privilege'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner:
        """Create an instance of ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner.parse_obj(obj)

        _obj = ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner.parse_obj({
            "id": obj.get("id"),
            "policy_id": obj.get("policyId"),
            "privilege_id": obj.get("privilegeId"),
            "requested_by": obj.get("requestedBy"),
            "is_temporary": obj.get("isTemporary"),
            "temporary_range": obj.get("temporaryRange"),
            "permissions": obj.get("permissions"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "environment_name": obj.get("environmentName"),
            "is_approved": obj.get("isApproved"),
            "privilege": ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPrivilege.from_dict(obj.get("privilege")) if obj.get("privilege") is not None else None,
            "policy": ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPolicy.from_dict(obj.get("policy")) if obj.get("policy") is not None else None,
            "reviewers": [ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerReviewersInner.from_dict(_item) for _item in obj.get("reviewers")] if obj.get("reviewers") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_rotation_providers_workspace_id_get200_response import ApiV1SecretRotationProvidersWorkspaceIdGet200Response  # noqa: E501

class TestApiV1SecretRotationProvidersWorkspaceIdGet200Response(unittest.TestCase):
    """ApiV1SecretRotationProvidersWorkspaceIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretRotationProvidersWorkspaceIdGet200Response:
        """Test ApiV1SecretRotationProvidersWorkspaceIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretRotationProvidersWorkspaceIdGet200Response`
        """
        model = ApiV1SecretRotationProvidersWorkspaceIdGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1SecretRotationProvidersWorkspaceIdGet200Response(
                providers = [
                    infisicalapi_client.models._api_v1_secret_rotation_providers__workspace_id__get_200_response_providers_inner._api_v1_secret_rotation_providers__workspaceId__get_200_response_providers_inner(
                        name = '', 
                        title = '', 
                        image = '', 
                        description = '', 
                        template = null, )
                    ]
            )
        else:
            return ApiV1SecretRotationProvidersWorkspaceIdGet200Response(
                providers = [
                    infisicalapi_client.models._api_v1_secret_rotation_providers__workspace_id__get_200_response_providers_inner._api_v1_secret_rotation_providers__workspaceId__get_200_response_providers_inner(
                        name = '', 
                        title = '', 
                        image = '', 
                        description = '', 
                        template = null, )
                    ],
        )
        """

    def testApiV1SecretRotationProvidersWorkspaceIdGet200Response(self):
        """Test ApiV1SecretRotationProvidersWorkspaceIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from infisicalapi_client.models.api_v1_secret_approval_requests_count_get200_response_approvals import ApiV1SecretApprovalRequestsCountGet200ResponseApprovals

class ApiV1SecretApprovalRequestsCountGet200Response(BaseModel):
    """
    ApiV1SecretApprovalRequestsCountGet200Response
    """
    approvals: ApiV1SecretApprovalRequestsCountGet200ResponseApprovals = Field(...)
    __properties = ["approvals"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsCountGet200Response:
        """Create an instance of ApiV1SecretApprovalRequestsCountGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of approvals
        if self.approvals:
            _dict['approvals'] = self.approvals.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsCountGet200Response:
        """Create an instance of ApiV1SecretApprovalRequestsCountGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsCountGet200Response.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsCountGet200Response.parse_obj({
            "approvals": ApiV1SecretApprovalRequestsCountGet200ResponseApprovals.from_dict(obj.get("approvals")) if obj.get("approvals") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1GroupsSlugUsersGet200ResponseUsersInner(BaseModel):
    """
    ApiV1GroupsSlugUsersGet200ResponseUsersInner
    """
    email: Optional[StrictStr] = None
    username: StrictStr = Field(...)
    first_name: Optional[StrictStr] = Field(default=None, alias="firstName")
    last_name: Optional[StrictStr] = Field(default=None, alias="lastName")
    id: StrictStr = Field(...)
    is_part_of_group: StrictBool = Field(default=..., alias="isPartOfGroup")
    __properties = ["email", "username", "firstName", "lastName", "id", "isPartOfGroup"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1GroupsSlugUsersGet200ResponseUsersInner:
        """Create an instance of ApiV1GroupsSlugUsersGet200ResponseUsersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if email (nullable) is None
        # and __fields_set__ contains the field
        if self.email is None and "email" in self.__fields_set__:
            _dict['email'] = None

        # set to None if first_name (nullable) is None
        # and __fields_set__ contains the field
        if self.first_name is None and "first_name" in self.__fields_set__:
            _dict['firstName'] = None

        # set to None if last_name (nullable) is None
        # and __fields_set__ contains the field
        if self.last_name is None and "last_name" in self.__fields_set__:
            _dict['lastName'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1GroupsSlugUsersGet200ResponseUsersInner:
        """Create an instance of ApiV1GroupsSlugUsersGet200ResponseUsersInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1GroupsSlugUsersGet200ResponseUsersInner.parse_obj(obj)

        _obj = ApiV1GroupsSlugUsersGet200ResponseUsersInner.parse_obj({
            "email": obj.get("email"),
            "username": obj.get("username"),
            "first_name": obj.get("firstName"),
            "last_name": obj.get("lastName"),
            "id": obj.get("id"),
            "is_part_of_group": obj.get("isPartOfGroup")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v3_signup_complete_account_signup_post200_response import ApiV3SignupCompleteAccountSignupPost200Response  # noqa: E501

class TestApiV3SignupCompleteAccountSignupPost200Response(unittest.TestCase):
    """ApiV3SignupCompleteAccountSignupPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV3SignupCompleteAccountSignupPost200Response:
        """Test ApiV3SignupCompleteAccountSignupPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV3SignupCompleteAccountSignupPost200Response`
        """
        model = ApiV3SignupCompleteAccountSignupPost200Response()  # noqa: E501
        if include_optional:
            return ApiV3SignupCompleteAccountSignupPost200Response(
                message = '',
                user = infisicalapi_client.models._api_v1_password_email_password_reset_verify_post_200_response_user._api_v1_password_email_password_reset_verify_post_200_response_user(
                    id = '', 
                    email = '', 
                    auth_methods = [
                        ''
                        ], 
                    super_admin = True, 
                    first_name = '', 
                    last_name = '', 
                    is_accepted = True, 
                    is_mfa_enabled = True, 
                    mfa_methods = [
                        ''
                        ], 
                    devices = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_ghost = True, 
                    username = '', 
                    is_email_verified = True, 
                    consecutive_failed_mfa_attempts = 1.337, 
                    is_locked = True, 
                    temporary_lock_date_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    consecutive_failed_password_attempts = 1.337, ),
                token = '',
                organization_id = ''
            )
        else:
            return ApiV3SignupCompleteAccountSignupPost200Response(
                message = '',
                user = infisicalapi_client.models._api_v1_password_email_password_reset_verify_post_200_response_user._api_v1_password_email_password_reset_verify_post_200_response_user(
                    id = '', 
                    email = '', 
                    auth_methods = [
                        ''
                        ], 
                    super_admin = True, 
                    first_name = '', 
                    last_name = '', 
                    is_accepted = True, 
                    is_mfa_enabled = True, 
                    mfa_methods = [
                        ''
                        ], 
                    devices = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_ghost = True, 
                    username = '', 
                    is_email_verified = True, 
                    consecutive_failed_mfa_attempts = 1.337, 
                    is_locked = True, 
                    temporary_lock_date_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    consecutive_failed_password_attempts = 1.337, ),
                token = '',
        )
        """

    def testApiV3SignupCompleteAccountSignupPost200Response(self):
        """Test ApiV3SignupCompleteAccountSignupPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ApiStatusGet200Response(BaseModel):
    """
    ApiStatusGet200Response
    """
    var_date: datetime = Field(default=..., alias="date")
    message: StrictStr = Field(...)
    email_configured: Optional[StrictBool] = Field(default=None, alias="emailConfigured")
    invite_only_signup: Optional[StrictBool] = Field(default=None, alias="inviteOnlySignup")
    redis_configured: Optional[StrictBool] = Field(default=None, alias="redisConfigured")
    secret_scanning_configured: Optional[StrictBool] = Field(default=None, alias="secretScanningConfigured")
    saml_default_org_slug: Optional[StrictStr] = Field(default=None, alias="samlDefaultOrgSlug")
    __properties = ["date", "message", "emailConfigured", "inviteOnlySignup", "redisConfigured", "secretScanningConfigured", "samlDefaultOrgSlug"]

    @validator('message')
    def message_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Ok'):
            raise ValueError("must be one of enum values ('Ok')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiStatusGet200Response:
        """Create an instance of ApiStatusGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiStatusGet200Response:
        """Create an instance of ApiStatusGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiStatusGet200Response.parse_obj(obj)

        _obj = ApiStatusGet200Response.parse_obj({
            "var_date": obj.get("date"),
            "message": obj.get("message"),
            "email_configured": obj.get("emailConfigured"),
            "invite_only_signup": obj.get("inviteOnlySignup"),
            "redis_configured": obj.get("redisConfigured"),
            "secret_scanning_configured": obj.get("secretScanningConfigured"),
            "saml_default_org_slug": obj.get("samlDefaultOrgSlug")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist, validator
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermissionConditions

class ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(BaseModel):
    """
    The permission object for the privilege.  # noqa: E501
    """
    actions: conlist(StrictStr, min_items=1) = Field(default=..., description="Describe what action an entity can take. Possible actions: create, edit, delete, and read")
    subject: StrictStr = Field(default=..., description="The entity this permission pertains to. Possible options: secrets, environments")
    conditions: ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermissionConditions = Field(...)
    __properties = ["actions", "subject", "conditions"]

    @validator('actions')
    def actions_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in ('read', 'create', 'edit', 'delete'):
                raise ValueError("each list item must be one of ('read', 'create', 'edit', 'delete')")
        return value

    @validator('subject')
    def subject_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('secrets'):
            raise ValueError("must be one of enum values ('secrets')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of conditions
        if self.conditions:
            _dict['conditions'] = self.conditions.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission.parse_obj(obj)

        _obj = ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission.parse_obj({
            "actions": obj.get("actions"),
            "subject": obj.get("subject"),
            "conditions": ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermissionConditions.from_dict(obj.get("conditions")) if obj.get("conditions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1LdapConfigGet200Response(BaseModel):
    """
    ApiV1LdapConfigGet200Response
    """
    id: StrictStr = Field(...)
    organization: StrictStr = Field(...)
    is_active: StrictBool = Field(default=..., alias="isActive")
    url: StrictStr = Field(...)
    bind_dn: StrictStr = Field(default=..., alias="bindDN")
    bind_pass: StrictStr = Field(default=..., alias="bindPass")
    unique_user_attribute: StrictStr = Field(default=..., alias="uniqueUserAttribute")
    search_base: StrictStr = Field(default=..., alias="searchBase")
    search_filter: StrictStr = Field(default=..., alias="searchFilter")
    group_search_base: StrictStr = Field(default=..., alias="groupSearchBase")
    group_search_filter: StrictStr = Field(default=..., alias="groupSearchFilter")
    ca_cert: StrictStr = Field(default=..., alias="caCert")
    __properties = ["id", "organization", "isActive", "url", "bindDN", "bindPass", "uniqueUserAttribute", "searchBase", "searchFilter", "groupSearchBase", "groupSearchFilter", "caCert"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1LdapConfigGet200Response:
        """Create an instance of ApiV1LdapConfigGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1LdapConfigGet200Response:
        """Create an instance of ApiV1LdapConfigGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1LdapConfigGet200Response.parse_obj(obj)

        _obj = ApiV1LdapConfigGet200Response.parse_obj({
            "id": obj.get("id"),
            "organization": obj.get("organization"),
            "is_active": obj.get("isActive"),
            "url": obj.get("url"),
            "bind_dn": obj.get("bindDN"),
            "bind_pass": obj.get("bindPass"),
            "unique_user_attribute": obj.get("uniqueUserAttribute"),
            "search_base": obj.get("searchBase"),
            "search_filter": obj.get("searchFilter"),
            "group_search_base": obj.get("groupSearchBase"),
            "group_search_filter": obj.get("groupSearchFilter"),
            "ca_cert": obj.get("caCert")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_external_kms_post200_response_external_kms import ApiV1ExternalKmsPost200ResponseExternalKms  # noqa: E501

class TestApiV1ExternalKmsPost200ResponseExternalKms(unittest.TestCase):
    """ApiV1ExternalKmsPost200ResponseExternalKms unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ExternalKmsPost200ResponseExternalKms:
        """Test ApiV1ExternalKmsPost200ResponseExternalKms
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ExternalKmsPost200ResponseExternalKms`
        """
        model = ApiV1ExternalKmsPost200ResponseExternalKms()  # noqa: E501
        if include_optional:
            return ApiV1ExternalKmsPost200ResponseExternalKms(
                id = '',
                description = '',
                is_disabled = True,
                is_reserved = True,
                org_id = '',
                slug = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                external = infisicalapi_client.models._api_v1_external_kms_post_200_response_external_kms_external._api_v1_external_kms_post_200_response_externalKms_external(
                    id = '', 
                    status = '', 
                    status_details = '', 
                    provider = '', )
            )
        else:
            return ApiV1ExternalKmsPost200ResponseExternalKms(
                id = '',
                org_id = '',
                slug = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                external = infisicalapi_client.models._api_v1_external_kms_post_200_response_external_kms_external._api_v1_external_kms_post_200_response_externalKms_external(
                    id = '', 
                    status = '', 
                    status_details = '', 
                    provider = '', ),
        )
        """

    def testApiV1ExternalKmsPost200ResponseExternalKms(self):
        """Test ApiV1ExternalKmsPost200ResponseExternalKms"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_rotations_get200_response_secret_rotations_inner_outputs_inner import ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner  # noqa: E501

class TestApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner(unittest.TestCase):
    """ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner:
        """Test ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner`
        """
        model = ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner()  # noqa: E501
        if include_optional:
            return ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner(
                key = '',
                secret = infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner_secret._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner_secret(
                    secret_key = '', 
                    id = '', 
                    version = 1.337, )
            )
        else:
            return ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner(
                key = '',
                secret = infisicalapi_client.models._api_v1_secret_rotations_get_200_response_secret_rotations_inner_outputs_inner_secret._api_v1_secret_rotations_get_200_response_secretRotations_inner_outputs_inner_secret(
                    secret_key = '', 
                    id = '', 
                    version = 1.337, ),
        )
        """

    def testApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner(self):
        """Test ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf  # noqa: E501

class TestApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(unittest.TestCase):
    """ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf:
        """Test ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf`
        """
        model = ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf()  # noqa: E501
        if include_optional:
            return ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(
                op = 'replace',
                value = infisicalapi_client.models._api_v1_scim_groups__group_id__patch_request_operations_inner_any_of_value._api_v1_scim_Groups__groupId__patch_request_Operations_inner_anyOf_value(
                    id = '', 
                    display_name = '', )
            )
        else:
            return ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(
                op = 'replace',
                value = infisicalapi_client.models._api_v1_scim_groups__group_id__patch_request_operations_inner_any_of_value._api_v1_scim_Groups__groupId__patch_request_Operations_inner_anyOf_value(
                    id = '', 
                    display_name = '', ),
        )
        """

    def testApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(self):
        """Test ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from infisicalapi_client.models.api_v1_integration_integration_id_patch_request_metadata import ApiV1IntegrationIntegrationIdPatchRequestMetadata

class ApiV1IntegrationIntegrationIdPatchRequest(BaseModel):
    """
    ApiV1IntegrationIntegrationIdPatchRequest
    """
    app: Optional[StrictStr] = Field(default=None, description="The name of the external integration providers app entity that you want to sync secrets with. Used in Netlify, GitHub, Vercel integrations.")
    app_id: Optional[StrictStr] = Field(default=None, alias="appId", description="The ID of the external integration providers app entity that you want to sync secrets with. Used in Netlify, GitHub, Vercel integrations.")
    is_active: StrictBool = Field(default=..., alias="isActive", description="Whether the integration should be active or disabled.")
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath", description="The path of the secrets to sync secrets from.")
    target_environment: StrictStr = Field(default=..., alias="targetEnvironment", description="The target environment of the integration provider. Used in cloudflare pages, TeamCity, Gitlab integrations.")
    owner: StrictStr = Field(default=..., description="External integration providers service entity owner. Used in Github.")
    environment: StrictStr = Field(default=..., description="The environment to sync secrets from.")
    metadata: Optional[ApiV1IntegrationIntegrationIdPatchRequestMetadata] = None
    __properties = ["app", "appId", "isActive", "secretPath", "targetEnvironment", "owner", "environment", "metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1IntegrationIntegrationIdPatchRequest:
        """Create an instance of ApiV1IntegrationIntegrationIdPatchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1IntegrationIntegrationIdPatchRequest:
        """Create an instance of ApiV1IntegrationIntegrationIdPatchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1IntegrationIntegrationIdPatchRequest.parse_obj(obj)

        _obj = ApiV1IntegrationIntegrationIdPatchRequest.parse_obj({
            "app": obj.get("app"),
            "app_id": obj.get("appId"),
            "is_active": obj.get("isActive"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "target_environment": obj.get("targetEnvironment"),
            "owner": obj.get("owner"),
            "environment": obj.get("environment"),
            "metadata": ApiV1IntegrationIntegrationIdPatchRequestMetadata.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, validator

class ApiV3SecretsRawSecretNamePostRequest(BaseModel):
    """
    ApiV3SecretsRawSecretNamePostRequest
    """
    workspace_id: StrictStr = Field(default=..., alias="workspaceId", description="The ID of the project to create the secret in.")
    environment: StrictStr = Field(default=..., description="The slug of the environment to create the secret in.")
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath", description="The path to create the secret in.")
    secret_value: StrictStr = Field(default=..., alias="secretValue", description="The value of the secret to create.")
    secret_comment: Optional[StrictStr] = Field(default='', alias="secretComment", description="Attach a comment to the secret.")
    tag_ids: Optional[conlist(StrictStr)] = Field(default=None, alias="tagIds", description="The ID of the tags to be attached to the created secret.")
    skip_multiline_encoding: Optional[StrictBool] = Field(default=None, alias="skipMultilineEncoding", description="Skip multiline encoding for the secret value.")
    type: Optional[StrictStr] = Field(default='shared', description="The type of the secret to create.")
    secret_reminder_repeat_days: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="secretReminderRepeatDays", description="Interval for secret rotation notifications, measured in days")
    secret_reminder_note: Optional[StrictStr] = Field(default=None, alias="secretReminderNote", description="Note to be attached in notification email")
    __properties = ["workspaceId", "environment", "secretPath", "secretValue", "secretComment", "tagIds", "skipMultilineEncoding", "type", "secretReminderRepeatDays", "secretReminderNote"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('shared', 'personal'):
            raise ValueError("must be one of enum values ('shared', 'personal')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3SecretsRawSecretNamePostRequest:
        """Create an instance of ApiV3SecretsRawSecretNamePostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if secret_reminder_repeat_days (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_repeat_days is None and "secret_reminder_repeat_days" in self.__fields_set__:
            _dict['secretReminderRepeatDays'] = None

        # set to None if secret_reminder_note (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_note is None and "secret_reminder_note" in self.__fields_set__:
            _dict['secretReminderNote'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3SecretsRawSecretNamePostRequest:
        """Create an instance of ApiV3SecretsRawSecretNamePostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3SecretsRawSecretNamePostRequest.parse_obj(obj)

        _obj = ApiV3SecretsRawSecretNamePostRequest.parse_obj({
            "workspace_id": obj.get("workspaceId"),
            "environment": obj.get("environment"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "secret_value": obj.get("secretValue"),
            "secret_comment": obj.get("secretComment") if obj.get("secretComment") is not None else '',
            "tag_ids": obj.get("tagIds"),
            "skip_multiline_encoding": obj.get("skipMultilineEncoding"),
            "type": obj.get("type") if obj.get("type") is not None else 'shared',
            "secret_reminder_repeat_days": obj.get("secretReminderRepeatDays"),
            "secret_reminder_note": obj.get("secretReminderNote")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_imports_secrets_raw_get200_response_secrets_inner import ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner  # noqa: E501

class TestApiV1SecretImportsSecretsRawGet200ResponseSecretsInner(unittest.TestCase):
    """ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner:
        """Test ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner`
        """
        model = ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner()  # noqa: E501
        if include_optional:
            return ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner(
                secret_path = '',
                environment = '',
                environment_info = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', ),
                folder_id = '',
                secrets = [
                    infisicalapi_client.models._api_v1_secret__secret_id__secret_versions_get_200_response_secret_versions_inner._api_v1_secret__secretId__secret_versions_get_200_response_secretVersions_inner(
                        id = '', 
                        _id = '', 
                        workspace = '', 
                        environment = '', 
                        version = 1.337, 
                        type = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner(
                secret_path = '',
                environment = '',
                environment_info = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', ),
                secrets = [
                    infisicalapi_client.models._api_v1_secret__secret_id__secret_versions_get_200_response_secret_versions_inner._api_v1_secret__secretId__secret_versions_get_200_response_secretVersions_inner(
                        id = '', 
                        _id = '', 
                        workspace = '', 
                        environment = '', 
                        version = 1.337, 
                        type = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testApiV1SecretImportsSecretsRawGet200ResponseSecretsInner(self):
        """Test ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
